<?php
error_reporting(0);
session_start();

// Function to sanitize input
function sanitize_input($input) {
    return htmlspecialchars(trim($input), ENT_QUOTES, 'UTF-8');
}

// Initialize stored content
$stored_content = '';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $category_file = $_SESSION['category'];

    // Get and sanitize the inputs
    $message = sanitize_input($_POST['message']);
    $category = sanitize_input($_POST['category']);

    // Get the current date in the format "d/m/Y"
    $current_date = date('d/m/Y');

    // Sanitize the category for the directory name (remove unwanted characters)
    $sanitized_category = preg_replace('/[^a-zA-Z0-9_-]/', '_', $category);

    // Define the directory and file path
    $directory = 'messages/' . $sanitized_category;
    $file_path = $directory . '/' . $category_file . '.html';

    // Check if the directory exists, if not, create it
    if (!is_dir($directory)) {
        mkdir($directory, 0755, true);
    }

    // Prepare the content to save
    $content = "<div class='message'>";
    if (isset($_SESSION['user'])) {
        $user = sanitize_input($_SESSION['user']);
    } else {
        $user = 'user';
    }
    $content .= "<p class='user'>$user</p>";
    $content .= "<p class='message-text'>$message</p></div>";

    // Save the content to the HTML file using fopen in append mode
    $file_handle = fopen($file_path, 'a');
    if ($file_handle) {
        fwrite($file_handle, $content);
        fclose($file_handle);
    }

    // Embed the stored HTML file content
    if (file_exists($file_path)) {
        $stored_content = file_get_contents($file_path);
    } else {
        $stored_content = '<p>Error: Could not retrieve the stored message file.</p>';
    }

    // Echo the updated content for Ajax response
    echo $stored_content;
    exit;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>PHP Chat</title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/all.min.css" />
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 0;
            background-color: #f4f4f4;
        }

        .chat-container {
            max-width: 600px;
            margin: 20px auto;
            background-color: #fff;
            border-radius: 10px;
            box-shadow: 0 0 20px rgba(0, 0, 0, 0.1);
            padding: 20px;
        }

        .chat-messages {
            height: 400px;
            overflow-y: auto;
            padding: 10px;
        }

        .message {
            display: flex;
            align-items: flex-start;
            margin-bottom: 10px;
        }

        .message .user {
            font-weight: bold;
            margin-right: 10px;
            color: #007bff;
        }

        .message .message-text {
            background-color: #f4f4f4;
            padding: 10px;
            border-radius: 10px;
            max-width: 80%;
            word-wrap: break-word;
        }

        .input-container {
            display: flex;
            margin-top: 10px;
        }

        .input-container input {
            flex-grow: 1;
            padding: 10px;
            border: 1px solid #ccc;
            border-radius: 5px;
            font-size: 16px;
        }

        .input-container button {
            background-color: #007bff;
            color: #fff;
            border: none;
            padding: 10px 20px;
            border-radius: 5px;
            cursor: pointer;
            font-size: 16px;
        }

        .input-container button:hover {
            background-color: #0056b3;
        }

        .slide-in {
            animation: slide-in 0.5s ease-in-out;
        }

        .slide-out {
            animation: slide-out 0.5s ease-in-out;
        }

        @keyframes slide-in {
            0% {
                transform: translateY(-100%);
            }
            100% {
                transform: translateY(0);
            }
        }

        @keyframes slide-out {
            0% {
                transform: translateY(0);
            }
            100% {
                transform: translateY(-100%);
            }
        }
    </style>
    <script src="https://cdn.jsdelivr.net/npm/vue/dist/vue.js"></script>
</head>
<body>
    <div id="app" class="chat-container">
        <div class="chat-messages">
            <?php echo $stored_content; ?>
        </div>
        <div class="input-container">
            <input type="text" v-model="message" placeholder="Type your message" />
            <button @click="sendMessage" :class="{ 'slide-in': showAnimation, 'slide-out': !showAnimation }">Send</button>
        </div>
    </div>

    <script>
        new Vue({
            el: '#app',
            data: {
                message: '',
                showAnimation: false
            },
            methods: {
                sendMessage() {
                    if (this.message.trim() !== '') {
                        const formData = new FormData();
                        formData.append('message', this.message);
                        formData.append('category', 'general'); // You can set a static category or create another input for category

                        fetch('', {
                            method: 'POST',
                            body: formData
                        })
                        .then(response => response.text())
                        .then(data => {
                            document.querySelector('.chat-messages').innerHTML = data;

                            // Show the animation
                            this.showAnimation = true;
                            setTimeout(() => {
                                this.showAnimation = false;
                            }, 500);

                            // Clear the input field
                            this.message = '';
                        });
                    }
                }
            }
        });
    </script>
</body>
</html>
